FlutterXr class

Implemented types

Constructors

FlutterXr()

Properties

flutterXRPigeon ↔ FlutterXRPigeon
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSpatialUiEnabled() Future<bool>
override
listenEvents(ValueChanged<String> listen) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes({Orbiter? leftOrbit, Orbiter? rightOrbit, Orbiter? topOrbit, Orbiter? bottomOrbit}) Future<Map<String, WidgetBuilder>>
override
requestFullSpaceMode() Future<void>
override
requestHomeSpaceMode() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited