FlutterXrInterface class abstract

Implementers

Constructors

FlutterXrInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSpatialUiEnabled() Future<bool>
listenEvents(ValueChanged<String> listen) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes({Orbiter leftOrbit, Orbiter rightOrbit, Orbiter topOrbit, Orbiter bottomOrbit}) Future<Map<String, WidgetBuilder>>
requestFullSpaceMode() Future<void>
requestHomeSpaceMode() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited