Orbiter class

Constructors

Orbiter(ContentEdge contentEdge, Alignment alignment, OrbiterOffsetType orbiterOffsetType, Widget child, {double? height, double? width})

Properties

alignment Alignment
getter/setter pair
child Widget
getter/setter pair
contentEdge ContentEdge
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
orbiterOffsetType OrbiterOffsetType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited